@@ -163,7 +163,7 @@ class Entries(dd.Table):
 
 
 class MyEntries(My, Entries):
-    required_roles = dd.login_required(BlogsReader)
+    required_roles = dd.login_required((BlogsReader, dd.SiteStaff))
     #~ master_key = 'user'
     column_names = "id pub_date entry_type title body *"
     # order_by = ["-modified"]
