@@ -1,4 +1,4 @@
-# Copyright 2017-2019 Rumma & Ko Ltd
+# Copyright 2017-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -14,7 +14,7 @@ class Plugin(ad.Plugin):
     verbose_name = _("Groups")
     # member_model = 'users.User'
     menu_group = 'system'
-    needs_plugins = ['lino.modlib.comments']
+    # needs_plugins = ['lino.modlib.comments']
 
     # def on_plugins_loaded(self, site):
     #     site.plugins.comments.configure(
