@@ -1,14 +1,10 @@
-# Copyright 2008-2018 Rumma & Ko Ltd
+# Copyright 2008-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
 Adds functionality for managing products.
 
-.. autosummary::
-   :toctree:
-
-    fixtures.food
-    fixtures.furniture
+See :doc:`/specs/products`.
 
 """
 
