@@ -30,9 +30,20 @@ class Category(BabelNamed, BabelPreviewable, Hierarchical):
 dd.update_field(Category, 'body', verbose_name=_("Long description"))
 
 
-class Categories(dd.Table):
+class ProductsTable(dd.Table):
+    # common things for Products and Categories
+    required_roles = dd.login_required(ProductsUser)
+    abstract = True
+
+    @classmethod
+    def hide_editing(cls, user_type):
+        if not user_type.has_required_roles([ProductsStaff]):
+            return True
+        return super(ProductsTable, cls).hide_editing(user_type)
+
+
+class Categories(ProductsTable):
     model = 'products.Category'
-    required_roles = dd.login_required(ProductsStaff)
     order_by = ["id"]
     column_names = "id parent name product_type *"
     detail_layout = """
@@ -41,7 +52,6 @@ class Categories(dd.Table):
     ProductsByCategory
     """
 
-
 class Product(BabelNamed, BabelPreviewable, Duplicable):
 
     class Meta:
@@ -64,8 +74,10 @@ class Product(BabelNamed, BabelPreviewable, Duplicable):
         yield "category"
 
     @dd.chooser()
-    def category_choices(self, product_type):
+    def category_choices(self, product_type, ar=None):
         qs = rt.models.products.Categories.request().data_iterator
+        if product_type is None and ar is not None:
+            product_type = ar.actor._product_type
         if product_type is not None:
             qs = qs.filter(product_type=product_type)
         return qs
@@ -130,9 +142,8 @@ class ProductDetail(dd.DetailLayout):
     """
 
 
-class BaseProducts(dd.Table):
+class BaseProducts(ProductsTable):
     abstract = True
-    required_roles = dd.login_required(ProductsUser)
     model = 'products.Product'
     order_by = ["name"]
     column_names = "id name category vat_class *"
