@@ -1,12 +1,12 @@
 # -*- coding: UTF-8 -*-
 # Copyright 2009-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
-# $ python setup.py test -s tests.PackagesTests
+# $ python setup.py test -s tests.test_packages
 
 
 SETUP_INFO = dict(
     name='lino-xl',
-    version='21.4.2',
+    version='21.6.0',
     install_requires=['lino'],  # odfpy dependency now in lino_xl.lib.appypod
     tests_require=[],
     description="The Lino Extensions Library",
@@ -38,6 +38,8 @@ lino_xl
 lino_xl.lib
 lino_xl.lib.addresses
 lino_xl.lib.addresses.fixtures
+lino_xl.lib.albums
+lino_xl.lib.albums.fixtures
 lino_xl.lib.ana
 lino_xl.lib.ana.fixtures
 lino_xl.lib.b2c
